@@ -20,7 +20,7 @@ uni_model  <- mixOmics::pls(x_tr, y_tr[[1]], ncomp = 3)
 # ------------------------------------------------------------------------------
 
 pls_spec <-
-  plsmod::pls(num_comp = 3) %>%
+  parsnip::pls(num_comp = 3) %>%
   set_engine("mixOmics") %>%
   set_mode("regression")
 
@@ -34,7 +34,7 @@ test_that('Multivariate model fitting', {
 
   expect_error(
     parsnip_pls_multi <-
-      plsmod::pls(num_comp = 3) %>%
+      parsnip::pls(num_comp = 3) %>%
       set_engine("mixOmics") %>%
       set_mode("regression") %>%
       fit_xy(x = x_tr, y = y_tr),
@@ -87,7 +87,7 @@ test_that('Univariate model fitting', {
 
   expect_error(
     parsnip_pls_uni <-
-      plsmod::pls(num_comp = 3) %>%
+      parsnip::pls(num_comp = 3) %>%
       set_engine("mixOmics") %>%
       set_mode("regression") %>%
       fit_xy(x = x_tr, y = y_tr[[1]]),
@@ -141,7 +141,7 @@ test_that('dummy variable encodings', {
   penguins <- na.omit(penguins)
   expect_error(
     parsnip_pls_multi <-
-      plsmod::pls(num_comp = 3) %>%
+      parsnip::pls(num_comp = 3) %>%
       set_engine("mixOmics") %>%
       set_mode("regression") %>%
       fit(body_mass_g ~ ., data = penguins),
